@@ -20,7 +20,7 @@
    Internet, or as Ben Pfaff, 12167 Airport Rd, DeWitt MI 48820, USA
    through more mundane means. */
 
-/* This is file avl.c in libavl, version 1.1.0. */
+/* This is file avl.c in libavl. */
 
 #if HAVE_CONFIG_H
 #include <config.h>
@@ -126,7 +126,7 @@ avl_destroy (avl_tree *tree, avl_node_func free_func)
       
       /* T1. */
       avl_node *an[AVL_MAX_HEIGHT];	/* Stack A: nodes. */
-      unsigned long ab = 0;		/* Stack A: bits. */
+      char ab[AVL_MAX_HEIGHT];		/* Stack A: bits. */
       int ap = 0;			/* Stack A: height. */
       avl_node *p = tree->root.link[0];
 
@@ -136,7 +136,7 @@ avl_destroy (avl_tree *tree, avl_node_func free_func)
 	  while (p != NULL)
 	    {
 	      /* T3. */
-	      ab &= ~(1ul << ap);
+	      ab[ap] = 0;
 	      an[ap++] = p;
 	      p = p->link[0];
 	    }
@@ -148,9 +148,9 @@ avl_destroy (avl_tree *tree, avl_node_func free_func)
 		goto done;
 
 	      p = an[--ap];
-	      if ((ab & (1ul << ap)) == 0)
+	      if (ab[ap] == 0)
 		{
-		  ab |= (1ul << ap++);
+		  ab[ap++] = 1;
 		  p = p->link[1];
 		  break;
 		}
@@ -646,21 +646,28 @@ avl_delete (avl_tree *tree, const void *item)
   for (;;)
     {
       /* D2. */
-      int diff = tree->cmp (item, p->data, tree->param);
+      int diff;
 
+      if (p == NULL)
+	return NULL;
+
+      diff = tree->cmp (item, p->data, tree->param);
       if (diff == 0)
 	break;
 
       /* D3, D4. */
       pa[k] = p;
       if (diff < 0)
-	p = p->link[0], a[k] = 0;
+	{
+	  p = p->link[0];
+	  a[k] = 0;
+	}
       else if (diff > 0)
-	p = p->link[1], a[k] = 1;
+	{
+	  p = p->link[1];
+	  a[k] = 1;
+	}
       k++;
-
-      if (p == NULL)
-	return NULL;
     }
   tree->count--;
   
@@ -946,7 +953,8 @@ print_contents (avl_tree *tree)
    root of the tree, PARENT should be INT_MIN, otherwise it should be
    the parent node value.  DIR is the direction that the current node
    is linked from the parent: -1 for left child, +1 for right child;
-   it is not used if PARENT is INT_MIN. */
+   it is not used if PARENT is INT_MIN.  Returns the height of the
+   tree rooted at NODE. */
 int
 recurse_tree (avl_node *node, int *count, int parent, int dir)
 {
@@ -958,17 +966,28 @@ recurse_tree (avl_node *node, int *count, int parent, int dir)
       (*count)++;
 
       if (nr - nl != node->bal)
-	printf (" Node %d is unbalanced: right height=%d, left height=%d, "
-		"difference=%d, but balance factor=%d.\n", d, nr, nl, nr - nl, node->bal), done = 1;
+	{
+	  printf (" Node %d is unbalanced: right height=%d, left height=%d, "
+		"difference=%d, but balance factor=%d.\n",
+		  d, nr, nl, nr - nl, node->bal);
+	  done = 1;
+	}
+      
       if (parent != INT_MIN)
 	{
 	  assert (dir == -1 || dir == +1);
 	  if (dir == -1 && d > parent)
-	    printf (" Node %d is smaller than its left child %d.\n",
-		    parent, d), done = 1;
+	    {
+	      printf (" Node %d is smaller than its left child %d.\n",
+		      parent, d);
+	      done = 1;
+	    }
 	  else if (dir == +1 && d < parent)
-	    printf (" Node %d is larger than its right child %d.\n",
-		    parent, d), done = 1;
+	    {
+	      printf (" Node %d is larger than its right child %d.\n",
+		      parent, d);
+	      done = 1;
+	    }
 	}
       assert (node->bal >= -1 && node->bal <= 1);
       return 1 + (nl > nr ? nl : nr);
@@ -983,7 +1002,11 @@ verify_tree (avl_tree *tree)
   int count = 0;
   recurse_tree (tree->root.link[0], &count, INT_MIN, 0);
   if (count != tree->count)
-    printf (" Tree has %d nodes, but tree count is %d.\n", count, tree->count), done = 1;
+    {
+      printf (" Tree has %d nodes, but tree count is %d.\n",
+	      count, tree->count);
+      done = 1;
+    }
   if (done)
     abort ();
 }
