@@ -20,7 +20,7 @@
    Internet, or as Ben Pfaff, 12167 Airport Rd, DeWitt MI 48820, USA
    through more mundane means. */
 
-/* This is file avlt.c in libavl, version 1.1.0. */
+/* This is file avlt.c in libavl. */
 
 #if HAVE_CONFIG_H
 #include <config.h>
@@ -113,7 +113,7 @@ avlt_destroy (avlt_tree *tree, avl_node_func free_func)
       
       /* T1. */
       avlt_node *an[AVL_MAX_HEIGHT];	/* Stack A: nodes. */
-      unsigned long ab = 0;		/* Stack A: bits. */
+      char ab[AVL_MAX_HEIGHT];		/* Stack A: bits. */
       int ap = 0;			/* Stack A: height. */
       avlt_node *p = tree->root.link[0];
 
@@ -123,7 +123,7 @@ avlt_destroy (avlt_tree *tree, avl_node_func free_func)
 	  for (;;)
 	    {
 	      /* T3. */
-	      ab &= ~(1ul << ap);
+	      ab[ap] = 0;
 	      an[ap++] = p;
 	      if (p->tag[0] == MINUS)
 		break;
@@ -137,9 +137,9 @@ avlt_destroy (avlt_tree *tree, avl_node_func free_func)
 		goto done;
 
 	      p = an[--ap];
-	      if ((ab & (1ul << ap)) == 0)
+	      if (ab[ap] == 0)
 		{
-		  ab |= (1ul << ap++);
+		  ab[ap++] = 1;
 		  if (p->tag[1] == MINUS)
 		    continue;
 		  p = p->link[1];
@@ -351,7 +351,7 @@ avlt_unthread (avlt_tree *tree)
       
   /* T1. */
   avlt_node *an[AVL_MAX_HEIGHT];	/* Stack A: nodes. */
-  unsigned long ab = 0;			/* Stack A: bits. */
+  char ab[AVL_MAX_HEIGHT];		/* Stack A: bits. */
   int ap = 0;				/* Stack A: height. */
   avlt_node *p;
 
@@ -364,7 +364,7 @@ avlt_unthread (avlt_tree *tree)
 	for (;;)
 	  {
 	    /* T3. */
-	    ab &= ~(1ul << ap);
+	    ab[ap] = 0;
 	    an[ap++] = p;
 	    if (p->tag[0] == MINUS)
 	      break;
@@ -378,9 +378,9 @@ avlt_unthread (avlt_tree *tree)
 	      goto done;
 
 	    p = an[--ap];
-	    if ((ab & (1ul << ap)) == 0)
+	    if (ab[ap] == 0)
 	      {
-		ab |= (1ul << ap++);
+		ab[ap++] = 1;
 		if (p->tag[1] == MINUS)
 		  continue;
 		p = p->link[1];
@@ -883,14 +883,20 @@ avlt_delete (avlt_tree *tree, const void *item)
       if (diff < 0)
 	{
 	  if (p->tag[0] == PLUS)
-	    p = p->link[0], a[k] = 0;
+	    {
+	      p = p->link[0];
+	      a[k] = 0;
+	    }
 	  else
 	    return NULL;
 	}
       else if (diff > 0)
 	{
 	  if (p->tag[1] == PLUS)
-	    p = p->link[1], a[k] = 1;
+	    {
+	      p = p->link[1];
+	      a[k] = 1;
+	    }
 	  else
 	    return NULL;
 	}
@@ -1264,7 +1270,8 @@ print_contents (avlt_tree *tree)
    root of the tree, PARENT should be INT_MIN, otherwise it should be
    the parent node value.  DIR is the direction that the current node
    is linked from the parent: -1 for left child, +1 for right child;
-   it is not used if PARENT is INT_MIN. */
+   it is not used if PARENT is INT_MIN.  Returns the height of the
+   tree rooted at NODE. */
 int
 recurse_tree (avlt_tree *tree, avlt_node *node, int *count, int parent,
 	      int dir, unsigned char *nodes, unsigned char *threads)
@@ -1279,7 +1286,10 @@ recurse_tree (avlt_tree *tree, avlt_node *node, int *count, int parent,
 
       assert (d >= 0 && d < TREE_SIZE);
       if (nodes[d / 8] & (1 << (d % 8)))
-	printf (" Arrived at node %d by two different paths.\n", d), done = 1;
+	{
+	  printf (" Arrived at node %d by two different paths.\n", d);
+	  done = 1;
+	}
       else
 	nodes[d / 8] |= 1 << (d % 8);
 
@@ -1302,21 +1312,35 @@ recurse_tree (avlt_tree *tree, avlt_node *node, int *count, int parent,
 	}
 
       if (nr - nl != node->bal)
-	printf (" Node %d has incorrect balance: right height=%d, "
-		"left height=%d, difference=%d, but balance factor=%d.\n",
-		d, nr, nl, nr - nl, node->bal), done = 1;
+	{
+	  printf (" Node %d has incorrect balance: right height=%d, "
+		  "left height=%d, difference=%d, but balance factor=%d.\n",
+		  d, nr, nl, nr - nl, node->bal);
+	  done = 1;
+	}
+      
       if (node->bal < -1 || node->bal > 1)
-	printf (" Node %d has invalid balance factor %d.\n",
-		d, node->bal), done = 1;
+	{
+	  printf (" Node %d has invalid balance factor %d.\n",
+		  d, node->bal);
+	  done = 1;
+	}
+      
       if (parent != INT_MIN)
 	{
 	  assert (dir == -1 || dir == +1);
 	  if (dir == -1 && d > parent)
-	    printf (" Node %d is smaller than its left child %d.\n",
-		    parent, d), done = 1;
+	    {
+	      printf (" Node %d is smaller than its left child %d.\n",
+		    parent, d);
+	      done = 1;
+	    }
 	  else if (dir == +1 && d < parent)
-	    printf (" Node %d is larger than its right child %d.\n",
-		    parent, d), done = 1;
+	    {
+	      printf (" Node %d is larger than its right child %d.\n",
+		      parent, d);
+	      done = 1;
+	    }
 	}
       assert (node->bal >= -1 && node->bal <= 1);
       return 1 + (nl > nr ? nl : nr);
@@ -1342,8 +1366,11 @@ verify_tree (avlt_tree *tree)
 		  threads);
     
     if (count != tree->count)
-      printf (" Tree should have %d nodes, but tree count by recursive "
-	      "descent is %d.\n", tree->count, count), done = 1;
+      {
+	printf (" Tree should have %d nodes, but tree count by recursive "
+		"descent is %d.\n", tree->count, count);
+	done = 1;
+      }
 
     for (i = 0; i < TREE_SIZE; i++)
       {
@@ -1351,8 +1378,11 @@ verify_tree (avlt_tree *tree)
 	int node = nodes[i / 8] & (1 << (i % 8));
 
 	if (thread && !node)
-	  printf (" A thread leads to ``node'' %d, which is not in the tree.",
-		  i), done = 1;
+	  {
+	    printf (" A thread leads to ``node'' %d, which is "
+		    "not in the tree.", i);
+	    done = 1;
+	  }
       }
   }
 
@@ -1365,15 +1395,24 @@ verify_tree (avlt_tree *tree)
     while (NULL != (data = avlt_next (tree, data)))
       {
 	if (((int) *data) < last)
-	  printf (" Misordered right threads.\n"), abort ();
+	  {
+	    printf (" Misordered right threads.\n");
+	    abort ();
+	  }
 	else if (((int) *data) == last)
-	  printf (" Loop in right threads detected on %d.\n", last), abort ();
+	  {
+	    printf (" Loop in right threads detected on %d.\n", last);
+	    abort ();
+	  }
 	last = (int) *data;
 	count++;
       }
     if (count != tree->count)
-      printf (" Tree should have %d nodes, but tree count by right threads "
-	      "is %d.\n", tree->count, count), done = 1;
+      {
+	printf (" Tree should have %d nodes, but tree count by right threads "
+		"is %d.\n", tree->count, count);
+	done = 1;
+      }
   }
 
   /* Check left threads. */
@@ -1385,15 +1424,24 @@ verify_tree (avlt_tree *tree)
     while (NULL != (data = avlt_prev (tree, data)))
       {
 	if (((int) *data) > last)
-	  printf (" Misordered left threads.\n"), abort ();
+	  {
+	    printf (" Misordered left threads.\n");
+	    abort ();
+	  }
 	else if (((int) *data) == last)
-	  printf (" Loop in left threads detected on %d.\n", last), abort ();
+	  {
+	    printf (" Loop in left threads detected on %d.\n", last);
+	    abort ();
+	  }
 	last = (int) *data;
 	count++;
       }
     if (count != tree->count)
-      printf (" Tree should have %d nodes, but tree count by left threads "
-	      "is %d.\n", tree->count, count), done = 1;
+      {
+	printf (" Tree should have %d nodes, but tree count by left threads "
+		"is %d.\n", tree->count, count);
+	done = 1;
+      }
   }
 
   if (done)
