@@ -20,7 +20,7 @@
    Internet, or as Ben Pfaff, 12167 Airport Rd, DeWitt MI 48820, USA
    through more mundane means. */
 
-/* This is file avltr.c in libavl, version 1.1.0. */
+/* This is file avltr.c in libavl. */
 
 #if HAVE_CONFIG_H
 #include <config.h>
@@ -117,7 +117,7 @@ avltr_destroy (avltr_tree *tree, avl_node_func free_func)
       
       /* T1. */
       avltr_node *an[AVL_MAX_HEIGHT];	/* Stack A: nodes. */
-      unsigned long ab = 0;		/* Stack A: bits. */
+      char ab[AVL_MAX_HEIGHT];		/* Stack A: bits. */
       int ap = 0;			/* Stack A: height. */
       avltr_node *p = tree->root.link[0];
 
@@ -127,7 +127,7 @@ avltr_destroy (avltr_tree *tree, avl_node_func free_func)
 	  while (p != NULL)
 	    {
 	      /* T3. */
-	      ab &= ~(1ul << ap);
+	      ab[ap] = 0;
 	      an[ap++] = p;
 	      p = p->link[0];
 	    }
@@ -139,9 +139,9 @@ avltr_destroy (avltr_tree *tree, avl_node_func free_func)
 		goto done;
 
 	      p = an[--ap];
-	      if ((ab & (1ul << ap)) == 0)
+	      if (ab[ap] == 0)
 		{
-		  ab |= (1ul << ap++);
+		  ab[ap++] = 1;
 		  if (p->rtag == MINUS)
 		    continue;
 		  p = p->link[1];
@@ -343,7 +343,7 @@ avltr_unthread (avltr_tree *tree)
       
   /* T1. */
   avltr_node *an[AVL_MAX_HEIGHT];	/* Stack A: nodes. */
-  unsigned long ab = 0;			/* Stack A: bits. */
+  char ab[AVL_MAX_HEIGHT];		/* Stack A: bits. */
   int ap = 0;				/* Stack A: height. */
   avltr_node *p;
 
@@ -356,7 +356,7 @@ avltr_unthread (avltr_tree *tree)
 	for (;;)
 	  {
 	    /* T3. */
-	    ab &= ~(1ul << ap);
+	    ab[ap] = 0;
 	    an[ap++] = p;
 	    if (p->link[0] == NULL)
 	      break;
@@ -370,9 +370,9 @@ avltr_unthread (avltr_tree *tree)
 	      goto done;
 
 	    p = an[--ap];
-	    if ((ab & (1ul << ap)) == 0)
+	    if (ab[ap] == 0)
 	      {
-		ab |= (1ul << ap++);
+		ab[ap++] = 1;
 		if (p->rtag == MINUS)
 		  continue;
 		p = p->link[1];
@@ -829,14 +829,20 @@ avltr_delete (avltr_tree *tree, const void *item)
       if (diff < 0)
 	{
 	  if (p->link[0] != NULL)
-	    p = p->link[0], a[k] = 0;
+	    {
+	      p = p->link[0];
+	      a[k] = 0;
+	    }
 	  else
 	    return NULL;
 	}
       else if (diff > 0)
 	{
 	  if (p->rtag == PLUS)
-	    p = p->link[1], a[k] = 1;
+	    {
+	      p = p->link[1];
+	      a[k] = 1;
+	    }
 	  else
 	    return NULL;
 	}
@@ -1225,7 +1231,8 @@ print_contents (avltr_tree *tree)
    root of the tree, PARENT should be INT_MIN, otherwise it should be
    the parent node value.  DIR is the direction that the current node
    is linked from the parent: -1 for left child, +1 for right child;
-   it is not used if PARENT is INT_MIN. */
+   it is not used if PARENT is INT_MIN.  Returns the height of the
+   tree rooted at NODE. */
 int
 recurse_tree (avltr_tree *tree, avltr_node *node, int *count, int parent,
 	      int dir, unsigned char *nodes, unsigned char *threads)
@@ -1240,7 +1247,10 @@ recurse_tree (avltr_tree *tree, avltr_node *node, int *count, int parent,
 
       assert (d >= 0 && d < TREE_SIZE);
       if (nodes[d / 8] & (1 << (d % 8)))
-	printf (" Arrived at node %d by two different paths.\n", d), done = 1;
+	{
+	  printf (" Arrived at node %d by two different paths.\n", d);
+	  done = 1;
+	}
       else
 	nodes[d / 8] |= 1 << (d % 8);
 
@@ -1250,7 +1260,10 @@ recurse_tree (avltr_tree *tree, avltr_node *node, int *count, int parent,
       if (node->rtag == PLUS)
 	{
 	  if (node->link[1] == NULL)
-	    printf (" Null thread link.\n"), done = 1;
+	    {
+	      printf (" Null thread link.\n");
+	      done = 1;
+	    }
 	  nr = recurse_tree (tree, node->link[1], count, d, 1, nodes, threads);
 	}
       else if (node->link[1] != &tree->root)
@@ -1258,26 +1271,42 @@ recurse_tree (avltr_tree *tree, avltr_node *node, int *count, int parent,
 	  int dr = (int) node->link[1]->data;
 	  assert (dr >= 0 && dr < TREE_SIZE);
 	  if (threads[dr / 8] & (1 << dr % 8))
-	    printf (" Multiple threads to node %d.\n", d), done = 1;
+	    {
+	      printf (" Multiple threads to node %d.\n", d);
+	      done = 1;
+	    }
 	  threads[dr / 8] |= 1 << (dr % 8);
 	}
 
       if (nr - nl != node->bal)
-	printf (" Node %d has incorrect balance: right height=%d, "
-		"left height=%d, difference=%d, but balance factor=%d.\n",
-		d, nr, nl, nr - nl, node->bal), done = 1;
+	{
+	  printf (" Node %d has incorrect balance: right height=%d, "
+		  "left height=%d, difference=%d, but balance factor=%d.\n",
+		  d, nr, nl, nr - nl, node->bal);
+	  done = 1;
+	}
+      
       if (node->bal < -1 || node->bal > 1)
-	printf (" Node %d has invalid balance factor %d.\n",
-		d, node->bal), done = 1;
+	{
+	  printf (" Node %d has invalid balance factor %d.\n", d, node->bal);
+	  done = 1;
+	}
+      
       if (parent != INT_MIN)
 	{
 	  assert (dir == -1 || dir == +1);
 	  if (dir == -1 && d > parent)
-	    printf (" Node %d is smaller than its left child %d.\n",
-		    parent, d), done = 1;
+	    {
+	      printf (" Node %d is smaller than its left child %d.\n",
+		      parent, d);
+	      done = 1;
+	    }
 	  else if (dir == +1 && d < parent)
-	    printf (" Node %d is larger than its right child %d.\n",
-		    parent, d), done = 1;
+	    {
+	      printf (" Node %d is larger than its right child %d.\n",
+		      parent, d);
+	      done = 1;
+	    }
 	}
       assert (node->bal >= -1 && node->bal <= 1);
       return 1 + (nl > nr ? nl : nr);
@@ -1303,8 +1332,11 @@ verify_tree (avltr_tree *tree)
 		  threads);
     
     if (count != tree->count)
-      printf (" Tree should have %d nodes, but tree count by recursive "
-	      "descent is %d.\n", tree->count, count), done = 1;
+      {
+	printf (" Tree should have %d nodes, but tree count by recursive "
+		"descent is %d.\n", tree->count, count);
+	done = 1;
+      }
 
     for (i = 0; i < TREE_SIZE; i++)
       {
@@ -1312,8 +1344,11 @@ verify_tree (avltr_tree *tree)
 	int node = nodes[i / 8] & (1 << (i % 8));
 
 	if (thread && !node)
-	  printf (" A thread leads to ``node'' %d, which is not in the tree.",
-		  i), done = 1;
+	  {
+	    printf (" A thread leads to ``node'' %d, "
+		    "which is not in the tree.", i);
+	    done = 1;
+	  }
       }
   }
 
@@ -1326,15 +1361,25 @@ verify_tree (avltr_tree *tree)
     while (NULL != (data = avltr_next (tree, data)))
       {
 	if (((int) *data) < last)
-	  printf (" Misordered right threads.\n"), abort ();
+	  {
+	    printf (" Misordered right threads.\n");
+	    abort ();
+	  }
 	else if (((int) *data) == last)
-	  printf (" Loop in right threads detected on %d.\n", last), abort ();
+	  {
+	    printf (" Loop in right threads detected on %d.\n", last);
+	    abort ();
+	  }
 	last = (int) *data;
 	count++;
       }
+
     if (count != tree->count)
-      printf (" Tree should have %d nodes, but tree count by right threads "
-	      "is %d.\n", tree->count, count), done = 1;
+      {
+	printf (" Tree should have %d nodes, but tree count by right threads "
+		"is %d.\n", tree->count, count);
+	done = 1;
+      }
   }
 
   if (done)
@@ -1464,7 +1509,10 @@ main (int argc, char **argv)
 	  if (tree->root.link[0] != NULL)
 	    compare_trees (tree->root.link[0], copy->root.link[0]);
 	  else if (copy->root.link[0] != NULL)
-	    printf (" Empty tree results in nonempty copy.\n"), abort ();
+	    {
+	      printf (" Empty tree results in nonempty copy.\n");
+	      abort ();
+	    }
 	  avltr_destroy (copy, NULL);
 
 	  if (i % 128 == 0)
