@@ -20,7 +20,7 @@
    Internet, or as Ben Pfaff, 12167 Airport Rd, DeWitt MI 48820, USA
    through more mundane means. */
 
-/* This is file avl-test.c in libavl, version 1.1.0. */
+/* This is file thread-test.c in libavl. */
 
 #if HAVE_CONFIG_H
 #include <config.h>
@@ -82,7 +82,7 @@ main (int argc, char **argv)
   for (iteration = 1; iteration <= N_ITERATIONS; iteration++)
     {
       avl_tree *tree;
-      avl_traverser trav = {0};
+      avl_traverser trav = AVL_TRAVERSER_INIT;
       void **nodep = NULL;
       void *node;
       int i;
